@@ -68,7 +68,7 @@ def expand_init(init):
     if typ == NamedInitializer:
         des = [expand_init(dp) for dp in init.name]
         return (des, expand_init(init.expr))
-    elif typ == ExprList:
+    elif typ in (InitList, ExprList):
         return [expand_init(expr) for expr in init.exprs]
     elif typ == Constant:
         return ['Constant', init.type, init.value]
@@ -1390,7 +1390,7 @@ class TestCParser_whole_code(TestCParser_base):
         # a ref in the visitor
         #
         self.assert_num_ID_refs(ps2, 'i', 3)
-        
+
         s3 = r'''
         void x(void)
         {
@@ -1406,6 +1406,15 @@ class TestCParser_whole_code(TestCParser_base):
         #
         self.assert_num_ID_refs(ps3, 'i', 2)
 
+        s4 = r'''
+        void x(void) {
+            for (int i = 0;;)
+                i;
+        }
+        '''
+        ps4 = self.parse(s4)
+        self.assert_num_ID_refs(ps4, 'i', 1)
+
     def _open_c_file(self, name):
         """ Find a c file by name, taking into account the current dir can be
             in a couple of typical places
